@@ -11,7 +11,7 @@ BEGIN {
     }
 }
 our $AUTHORITY = 'cpan:BEROV';
-our $VERSION   = '0.55';
+our $VERSION   = '0.56';
 our $CODENAME  = 'U+2C04 GLAGOLITIC CAPITAL LETTER DOBRO (Ⰴ)';
 
 use Ado::Control;
@@ -23,7 +23,7 @@ has sessions => sub { Ado::Sessions::get_instance(shift->config) };
 # This method will run once at server start
 sub startup {
     my $app = shift;
-    $app->load_config()->load_plugins()->load_routes()->define_mime_types()->define_hooks();
+    $app->load_config()->load_plugins()->load_routes()->define_mime_types();
     return;
 }
 
@@ -103,11 +103,6 @@ sub define_mime_types {
     return $app;
 }
 
-sub define_hooks {
-    my $app = shift;
-    return $app;
-}
-
 1;
 
 
@@ -156,7 +151,7 @@ the following new ones.
 =head2 startup
 
 The startup method is where everything begins. Returns void.
-The following methods are listed in the order they are innvoked in L</startup>.
+The following methods are listed in the order they are invoked in L</startup>.
 
 =head2 load_config
 
@@ -198,12 +193,6 @@ Returns $app.
 Defines any MIME types listed in C<ado.conf> in C<types =E<gt> {...}>.
 Returns $app.
 
-
-=head2 define_hooks
-
-B<May be never implemented>. Plugins can define code which is run in L<Mojolicious/hooks>.
-Returns $app.
-
 =head1 SPONSORS
 
 The original author.
